<?php
// Exit if accessed directly
if ( !defined('ABSPATH')) exit;

function ningxia_child_enqueue_styles() {
 $parent_style = 'ningxia-style';
 wp_enqueue_style( $parent_style, get_template_directory_uri().'/style.css', array(), wp_get_theme()->parent()->get( 'Version' ) );
 wp_enqueue_style( 'ningxia-child-style', get_stylesheet_directory_uri().'/style.css', array( $parent_style), wp_get_theme()->get('Version') );
}
add_action( 'wp_enqueue_scripts', 'ningxia_child_enqueue_styles' );

function ningxia_child_setup() {

 /*
  * Make Twenty Fourteen available for translation.
  *
  * Translations can be added to the /languages/ directory.
  * If you're building a theme based on Twenty Fourteen, use a find and
  * replace to change 'twentyfourteen' to the name of your theme in all
  * template files.
  */

 register_nav_menus( array(
   'liftoff'  => __( 'Liftoff! Navigation', 'ningxia'),
   'en-garde' => __( 'En Garde Navigation', 'ningxia')
 ) );
}
add_action( 'after_setup_theme', 'ningxia_child_setup' );

function ningxia_child_page_template_styles() {
 if ( is_page_template( 'chronicle-page.php') ) {
  wp_enqueue_style( 'page-template', get_stylesheet_directory_uri() . '/chronicle.css', array(), wp_get_theme()->get('Version') );
 }
}
add_action( 'wp_enqueue_scripts', 'ningxia_child_page_template_styles' );

function ningxia_child_tag_cloud_args( $cloud_args ){
 $cloud_args['smallest'] = 8;
 $cloud_args['largest'] = 28;
 $cloud_args['unit'] = 'px';
 return $cloud_args;
}

add_filter('widget_tag_cloud_args', 'ningxia_child_tag_cloud_args');

/* --------------------- Functions for updating themes ------------------------------ */
function ningxia_child_get_remote_update_from( $sitebase, $uploads, $slug ) {
 $url = $uploads . '/jsons/' . $slug . '.json';
 $remote =  wp_remote_get( $url, array( 'timeout' => 10, 'headers' => array( 'Accept' => 'application/json' ) ) );
 if ( !is_wp_error( $remote ) && isset( $remote['response']['code'] ) && 200 == $remote['response']['code'] && ! empty( $remote['body'] ) ) {
  $remote['uploads'] = $uploads;
  $remote['sitebase'] = $sitebase;
 }
 return $remote;
}
function ningxia_child_get_remote_update_info( $slug ) {
 $remote = get_transient( 'djv_update_' . $slug );
 if (false == $remote || is_wp_error($remote) || !isset( $remote['response']['code'] ) || 200 !== $remote['response']['code'] || empty( $remote['body'] ) ) {
 	$sitebase = get_site_url( );
 	$upload_dir = wp_upload_dir( );
 	if ( is_ssl() ) { $upload_dir['baseurl'] = str_replace( 'http://', 'https://', $upload_dir['baseurl'] ); }
 	$remote = ningxia_child_get_remote_update_from( $sitebase, $upload_dir['baseurl'], $slug );
 	if ( !is_wp_error( $remote ) && isset( $remote['response']['code'] ) && 200 == $remote['response']['code'] && ! empty( $remote['body'] ) ) {
 		set_transient( 'djv_update_' . $slug, $remote, 10 ); // Save for only 10 seconds here
 	} else {
 		$remote = ningxia_child_get_remote_update_from( 'https://blog.tremlas.com', 'https://blog.tremlas.com/wp-content/uploads', $slug );
 		if ( !is_wp_error( $remote ) && isset( $remote['response']['code'] ) && 200 == $remote['response']['code'] && ! empty( $remote['body'] ) ) {
 			set_transient( 'djv_update_' . $slug, $remote, 43200 ); // Save for 12 hours
 		}
 	}
 }
 if ( !is_wp_error( $remote ) && isset( $remote['response']['code'] ) && 200 == $remote['response']['code'] && ! empty( $remote['body'] ) ) {
  $body = json_decode( $remote['body'] );
  $changelog = $body->sections->changelog;
  $changelog = str_replace( '<a href="', '<a href="' . $remote['uploads'] . '/' , $changelog );
  $info =array(
    'name'          => 'Ningxia Child',
    'slug'          => $slug,
    'version'       => $body->version,
    'requires'      => $body->requires,
    'author'        => '<a href="' . $body->author_profile . '">' . $body->author . '</a>',
    'download_link' => $remote['uploads'] . '/' . $body->download_url,
    'trunk'         => $remote['uploads'] . '/' . $body->download_url,
    'last_updated'  => $body->last_updated,
    'sections'      => array(
      'description'  => implode( "\n", $body->sections->description ),
      'installation' => implode( "\n", $body->sections->installation ),
      'changelog'    => implode( "\n", $changelog ),
    ),
    'homepage'      => $remote['sitebase'] . '/' . $body->homepage
  );
  return $info;
 }
 return false;
}

function ningxia_child_check_for_update( $slug ) {
 $info = ningxia_child_get_remote_update_info( $slug );
 if ( false == $info ) {
  return false;
 }
 if ( version_compare( '3.165.0', $info['version'], '<' ) && version_compare( $info['requires'], get_bloginfo( 'version' ), '<' ) ) {
  $update = array(
    'slug'          => $slug,
    'new_version'   => $info['version'],
    'url'           => $info['homepage'],
    'package'       => $info['download_link'],
    'icons'         => array(),
    'banners'       => array(),
    'banners_rtl'   => array(),
    'tested'        => '',
    'requires_php'  => '',
    'compatability' => new StdClass()
  );
  return $update;
 } else {
  return false;
 }
}

function ningxia_child_pre_set_site_transient_update_themes( $transient ) {
 // Check for update
 $themeslug = 'NingxiaChild';
 $update = ningxia_child_check_for_update( $themeslug );
 if ( $update ) {
  $transient->response[$themeslug] = $update;
 }
 return $transient;
}
add_filter( 'pre_set_site_transient_update_themes', 'ningxia_child_pre_set_site_transient_update_themes' );

function ningxia_child_theme_info( $result, $action, $args ) {
 $slug = 'NingxiaChild';
 if ( 'plugin_information' !== $action ) {
  return $result;
 }
 if ( $slug !== $args->slug) {
  return $result;
 }
 return ningxia_child_get_remote_update_info( $slug );
}
add_filter( 'themes_api', 'ningxia_child_theme_info', 10, 3 );

?>